Thin wrappers around the underlying HTML parser.
[NodeRef] is the reference-counted DOM node type used throughout the crate.
[parse_html] parses a complete HTML document into a [NodeRef] tree.
Structs
- Attributes
- Convenience wrapper around a indexmap that adds method for attributes in the null namespace.
- NodeRef
- A strong reference to a node.
Traits
Functions
- new_
html_ element - Create a new, detached HTML element node with the given tag name and no attributes or children.
- parse_
html - Parse an HTML string into a
NodeRefdocument tree.